Option Explicit

'
' Visual Basic Data Access constants
'
' OPTIONS values
Global Const DB_DENYWRITE = &H1
Global Const DB_DENYREAD = &H2
Global Const DB_READONLY = &H4
Global Const DB_APPENDONLY = &H8
Global Const DB_INCONSISTENT = &H10
Global Const DB_CONSISTENT = &H20
Global Const DB_SQLPASSTHROUGH = &H40

' RecordSet Attributes
Global Const DB_UPDATABLE = &H1
Global Const DB_BOOKMARKABLE = &H2
Global Const DB_ROLLBACKABLE = &H4
Global Const DB_RESTARTABLE = &H8
Global Const DB_NOINSERTS = &H10

' SetDataAccessOption
Global Const DB_INITPATH = 1

' Field Attributes
Global Const DB_FIELDFIXED = &H1
Global Const DB_FIELDTAGGED = &H2
Global Const DB_FIELDNOTNULL = &H4
Global Const DB_FIELDVERSION = &H8
Global Const DB_FIELDCOUNTER = &H10
Global Const DB_FIELDUPDATABLE = &H20
Global Const DB_FIELDGRAPHIC = &H200

' Field Data Types
Global Const DB_BOOLEAN = 1
Global Const DB_BYTE = 2
Global Const DB_INTEGER = 3
Global Const DB_LONG = 4
Global Const DB_CURRENCY = 5
Global Const DB_SINGLE = 6
Global Const DB_DOUBLE = 7
Global Const DB_DATE = 8
Global Const DB_BINARY = 9
Global Const DB_TEXT = 10
Global Const DB_LONGBINARY = 11
Global Const DB_MEMO = 12

' ListTables Attributes
Global Const DB_SYSTEMOBJECT = &H80000002
Global Const DB_TABLE = 1
Global Const DB_ATTACHEDTABLE = 6
Global Const DB_ATTACHEDODBC = 4
Global Const DB_QUERYDEF = 5
Global Const DB_QACTION = &HF0
Global Const DB_ATTACHEXCLUSIVE = &H40000000
Global Const DB_ATTACHSAVEPWD = &H20000000

' Query types
Global Const DB_QCROSSTAB = &H10
Global Const DB_QDELETE = &H20
Global Const DB_QUPDATE = &H30
Global Const DB_QAPPEND = &H40
Global Const DB_QMAKETABLE = &H50

' Index Attributes
Global Const DB_UNIQUE = 1
Global Const DB_PRIMARY = 2
Global Const DB_NONULLS = 3
Global Const DB_DESCENDING = 1

' CreateDatabase Language constants
Global Const DB_CREATE_GENERAL = ";LANGID=0x0809;CP=1252;COUNTRY=0"
Global Const DB_CREATE_SPANISH = ";LANGID=0x040A;CP=1252;COUNTRY=0"
Global Const DB_CREATE_DUTCH = ";LANGID=0x0413;CP=1252;COUNTRY=0"
Global Const DB_CREATE_SWEDFIN = ";LANGID=0x040C;CP=1252;COUNTRY=0"   'VB3 and Access 1.1 Databases
Global Const DB_CREATE_NORWDAN = ";LANGID=0x0414;CP=1252;COUNTRY=0"   'VB3 and Access 1.1 Databases
Global Const DB_CREATE_ICELANDIC = ";LANGID=0x040F;CP=1252;COUNTRY=0" 'VB3 and Access 1.1 Databases
Global Const DB_CREATE_NORDIC = ";LANGID=0x041D;CP=1252;COUNTRY=0"    'Access 1.0 Databases only

Global gDefaultDatabase As database

Function DLookup (ByVal FieldName As String, ByVal RecSource As String, ByVal Criteria As String) As Variant

    Dim dsResult As dynaset
    Dim ReturnValue As Variant

    'Create a dynset based on the record source or SQL string provided
    Set dsResult = gDefaultDatabase.CreateDynaset(RecSource)

    'Find the first record that meets the criteria provided
    dsResult.FindFirst Criteria

    If Not dsResult.NoMatch Then

	'Return the value of the field
	DLookup = dsResult(FieldName).Value

    Else
	DLookup = Null

    End If



' In order to use the above function you will need to
' declare a global Database
' object called gDefaultDatabase which is set
' to the current database before the
' call to DLookup.
 
End Function

Function FillListFromQuery (db As String, cs As String, qry As String, fld As String, ctl As Control) As String
'-----------------------------------------------------------
' This function will fill a listbox or a combo box with a dynaset
' in an existing database
'
' Parameters:
'    db As String       example: "c:\access\mydb.mdb"
'    cs As String       ConnectString
'    qry As String      can be a table, a dynaset, or an SQL statement
'    fld As String      field in the dynaset to load into the listbox
'    ctl As Control     name of the control to fille

    Dim tdb As database
    Dim tds As dynaset
    Dim ssize As Long

    On Error GoTo Err_FillListFromQuery_Handler

    FillListFromQuery = ""

    Set tdb = OpenDatabase(db, False, True, cs)
    Set tds = tdb.CreateDynaset(qry, DB_READONLY)

    ctl.Clear

    Do Until tds.EOF
	ssize = ssize + Len(tds(fld))
	If ssize > 50000 Then
	    FillListFromQuery = "Out of memory: " & ctl.ListCount & " rows returned"
	    Exit Do
	End If
	ctl.AddItem tds(fld)
	tds.MoveNext
    Loop
    

    tds.Close
    tdb.Close
    
    Exit Function

Err_FillListFromQuery_Handler:
    FillListFromQuery = Error$
    Resume Err_FillListFromQuery_Exit
    
Err_FillListFromQuery_Exit:
    Exit Function

End Function

Function QueryExists (qname As Variant) As Integer
' In order to use this function you will need to
' declare a global Database object called gDefaultDatabase
' which is set to the current database before the
' call to this function

    Const DB_QUERYDEF = &H5

    QueryExists = False

    Dim ss As snapshot
    Set ss = gDefaultDatabase.ListTables()
    
    If ss.RecordCount <> 0 Then
	ss.MoveFirst
	Do Until ss.EOF
	    'Debug.Print ss("Name")
	    If ss("Name") = qname Then
		If ss("TableType") = DB_QUERYDEF Then
		    QueryExists = True
		    Exit Do
		End If

	    End If
	    ss.MoveNext
	Loop
    End If


End Function

